/* khotswap.cpp

khotswap - KDE frontend for the hotswap program.

Copyright (C) 2003-2008 Tim Stadelmann

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
02111-1307, USA.  */


/** HEADER FILES **/

/* autoconf */
#if HAVE_CONFIG_H
#  include <config.h>
#endif

/* KDE header files */
#include <kaboutdata.h>
#include <kapplication.h>
#include <kcmdlineargs.h>
#include <klocale.h>

/* program specific header files */
#include "hotswapform.hpp"


/** MACROS **/

#ifndef IDE_CONTROLLER
#  define IDE_CONTROLLER "1"
#endif /* IDE_CONTROLLER */

#ifndef UDEVADM_PATH
#define UDEVADM_PATH ("/sbin/udevadm")
#endif /* UDEVADM_PATH */

#ifndef HOTSWAP_PATH
#  define HOTSWAP_PATH "hotswap"
#endif /* HOTSWAP_PATH */


/** FUNCTIONS **/

int
main (int argc, char* argv[])
{
  /* Data describing the application.  This is used in the About
     dialog and on the command line.  */
  KAboutData *about
    = new KAboutData ("khotswap",
		      I18N_NOOP ("Hotswap"),
		      VERSION,
		      I18N_NOOP ("Supports hotswapping IDE peripherals."),
		      KAboutData::License_GPL,
		      "© 2003-2008 Tim Stadelmann",
		      0,
		      "http://timstadelmann.de/",
		      "mail@timstadelmann.de");

  /* Initialize the command line arguments.  */
  KCmdLineArgs::init (argc, argv, about);

  /* Define application specific command line options and add them.  */
  static KCmdLineOptions options[] =
    {
      {"ide-controller N",
       I18N_NOOP ("Use IDE controller N"),
       IDE_CONTROLLER},
      {"udevadm-path PATH",
       I18N_NOOP ("Look for the `udevadm' utility at the\n"
		  "location given by PATH"),
       UDEVADM_PATH},
      {"hotswap-path PATH",
       I18N_NOOP ("Look for the `hotswap' backend at the\n"
		  "location given by PATH"),
       HOTSWAP_PATH},
      {"systray",
       I18N_NOOP ("Only show system tray icon at startup"),
       0},
      {0, 0, 0}
    };

  KCmdLineArgs::addCmdLineOptions (options);

  /* Create the application object.  */
  KApplication application (argc, argv);

  /* Make the parsed command line arguments available.  */
  KCmdLineArgs *args = KCmdLineArgs::parsedArgs ();

  /* Create a HotswapForm widget as the main widget.  */

  unsigned int ide_controller = args->getOption ("ide-controller").toUInt ();
  QString udevadm_path = args->getOption ("udevadm-path");
  QString hotswap_path = args->getOption ("hotswap-path");
  
  HotswapForm *main_form;
  
  /* There can only be  one instance.  */
  const int instance = 1;

  if (kapp->isRestored () && KMainWindow::canBeRestored (instance))
    {
      main_form
	= new HotswapForm (0, ide_controller, udevadm_path, hotswap_path);
      main_form->restore (instance, false);
      if (!main_form->systray)
	main_form->show ();
    }
  else
    {
      main_form
	= new HotswapForm (0, ide_controller, udevadm_path, hotswap_path);
      if (!args->isSet ("systray"))
	main_form->show ();
    }
  
  /* Enter the event loop and pass on the return value.  */
  return application.exec ();
}
